@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2017 Red Hat, Inc.
+ * Copyright © 2012 – 2019 Red Hat, Inc.
  * Copyright © 2014 Saurav Agarwalla
  *
  * This program is free software: you can redistribute it and/or modify
@@ -45,7 +45,6 @@ struct _PhotosMainToolbar
 {
   GtkBox parent_instance;
   GAction *search;
-  GSimpleAction *gear_menu;
   GtkWidget *favorite_button;
   GtkWidget *header_bar;
   GtkWidget *remote_display_button;
@@ -232,6 +231,26 @@ photos_main_toolbar_add_devices_button (PhotosMainToolbar *self)
 }
 
 
+static void
+photos_main_toolbar_add_primary_menu_button (PhotosMainToolbar *self)
+{
+  GMenu *primary_menu;
+  g_autoptr (GtkBuilder) builder = NULL;
+  GtkWidget *menu_button;
+  GtkWidget *image;
+
+  builder = gtk_builder_new_from_resource ("/org/gnome/Photos/primary-menu.ui");
+
+  primary_menu = G_MENU (gtk_builder_get_object (builder, "primary-menu"));
+  image = gtk_image_new_from_icon_name ("open-menu-symbolic", GTK_ICON_SIZE_BUTTON);
+  menu_button = gtk_menu_button_new ();
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "app.primary-menu");
+  gtk_button_set_image (GTK_BUTTON (menu_button), image);
+  gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), G_MENU_MODEL (primary_menu));
+  gtk_header_bar_pack_end (GTK_HEADER_BAR (self->header_bar), menu_button);
+}
+
+
 static void
 photos_main_toolbar_remote_display_button_clicked (PhotosMainToolbar *self)
 {
@@ -361,8 +380,6 @@ photos_main_toolbar_clear_toolbar (PhotosMainToolbar *self)
   gtk_container_foreach (GTK_CONTAINER (self->header_bar), (GtkCallback) gtk_widget_destroy, NULL);
   context = gtk_widget_get_style_context (self->header_bar);
   gtk_style_context_remove_class (context, "selection-mode");
-
-  g_simple_action_set_enabled (self->gear_menu, FALSE);
 }
 
 
@@ -441,6 +458,7 @@ photos_main_toolbar_populate_for_collection_view (PhotosMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->header_bar), TRUE);
 
   photos_main_toolbar_add_back_button (self);
+  photos_main_toolbar_add_primary_menu_button (self);
   photos_main_toolbar_add_selection_button (self);
   photos_main_toolbar_add_search_button (self);
 }
@@ -453,6 +471,7 @@ photos_main_toolbar_populate_for_collections (PhotosMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->header_bar), TRUE);
 
   photos_main_toolbar_add_devices_button (self);
+  photos_main_toolbar_add_primary_menu_button (self);
   photos_main_toolbar_add_selection_button (self);
   photos_main_toolbar_add_search_button (self);
 }
@@ -484,6 +503,7 @@ photos_main_toolbar_populate_for_favorites (PhotosMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->header_bar), TRUE);
 
   photos_main_toolbar_add_devices_button (self);
+  photos_main_toolbar_add_primary_menu_button (self);
   photos_main_toolbar_add_selection_button (self);
   photos_main_toolbar_add_search_button (self);
 }
@@ -523,6 +543,7 @@ photos_main_toolbar_populate_for_overview (PhotosMainToolbar *self)
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->header_bar), TRUE);
 
   photos_main_toolbar_add_devices_button (self);
+  photos_main_toolbar_add_primary_menu_button (self);
   photos_main_toolbar_add_selection_button (self);
   photos_main_toolbar_add_search_button (self);
 }
@@ -547,15 +568,13 @@ photos_main_toolbar_populate_for_preview (PhotosMainToolbar *self)
   photos_main_toolbar_add_back_button (self);
 
   preview_menu = photos_main_toolbar_create_preview_menu (self);
-  image = gtk_image_new_from_icon_name ("open-menu-symbolic", GTK_ICON_SIZE_BUTTON);
+  image = gtk_image_new_from_icon_name ("view-more-symbolic", GTK_ICON_SIZE_BUTTON);
   menu_button = gtk_menu_button_new ();
-  gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "app.gear-menu");
+  gtk_actionable_set_action_name (GTK_ACTIONABLE (menu_button), "app.preview-menu");
   gtk_button_set_image (GTK_BUTTON (menu_button), image);
   gtk_menu_button_set_menu_model (GTK_MENU_BUTTON (menu_button), G_MENU_MODEL (preview_menu));
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self->header_bar), menu_button);
 
-  g_simple_action_set_enabled (self->gear_menu, TRUE);
-
   share_button = gtk_button_new_from_icon_name ("emblem-shared-symbolic", GTK_ICON_SIZE_BUTTON);
   gtk_actionable_set_action_name (GTK_ACTIONABLE (share_button), "app.share-current");
   gtk_header_bar_pack_end (GTK_HEADER_BAR (self->header_bar), share_button);
@@ -596,6 +615,7 @@ photos_main_toolbar_populate_for_search (PhotosMainToolbar *self)
   gtk_header_bar_set_custom_title (GTK_HEADER_BAR (self->header_bar), self->stack_switcher);
   gtk_header_bar_set_show_close_button (GTK_HEADER_BAR (self->header_bar), TRUE);
 
+  photos_main_toolbar_add_primary_menu_button (self);
   photos_main_toolbar_add_selection_button (self);
   photos_main_toolbar_add_search_button (self);
 }
@@ -693,7 +713,6 @@ photos_main_toolbar_init (PhotosMainToolbar *self)
   app = g_application_get_default ();
   state = photos_search_context_get_state (PHOTOS_SEARCH_CONTEXT (app));
 
-  self->gear_menu = G_SIMPLE_ACTION (g_action_map_lookup_action (G_ACTION_MAP (app), "gear-menu"));
   self->search = g_action_map_lookup_action (G_ACTION_MAP (app), "search");
 
   action = g_action_map_lookup_action (G_ACTION_MAP (app), "selection-mode");
