@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2017 Red Hat, Inc.
+ * Copyright © 2017 – 2019 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -266,7 +266,8 @@ photos_thumbnail_factory_initable_init (GInitable *initable, GCancellable *cance
                             G_CALLBACK (photos_thumbnail_factory_authorize_authenticated_peer),
                             self);
 
-  self->dbus_server = g_dbus_server_new_sync (address, G_DBUS_SERVER_FLAGS_NONE,
+  self->dbus_server = g_dbus_server_new_sync (address,
+                                              G_DBUS_SERVER_FLAGS_NONE,
                                               guid,
                                               observer,
                                               cancellable,
