@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2020 Red Hat, Inc.
  * Copyright © 2009 Yorba Foundation
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,6 +26,8 @@
 
 #include "config.h"
 
+#include <math.h>
+
 #include <gdk/gdk.h>
 #include <glib.h>
 #include <tracker-sparql.h>
@@ -915,6 +917,25 @@ photos_utils_get_controller (PhotosWindowMode mode,
 }
 
 
+gdouble
+photos_utils_get_double_from_sparql_cursor_with_default (TrackerSparqlCursor *cursor,
+                                                         PhotosQueryColumns column,
+                                                         gdouble default_value)
+{
+  TrackerSparqlValueType value_type;
+  gdouble ret_val = default_value;
+
+  value_type = tracker_sparql_cursor_get_value_type (cursor, column);
+  if (value_type == TRACKER_SPARQL_VALUE_TYPE_UNBOUND)
+    goto out;
+
+  ret_val = tracker_sparql_cursor_get_double (cursor, column);
+
+ out:
+  return ret_val;
+}
+
+
 gchar *
 photos_utils_get_extension_from_mime_type (const gchar *mime_type)
 {
@@ -969,6 +990,48 @@ photos_utils_get_icon_size_unscaled (void)
 }
 
 
+gint64
+photos_utils_get_integer_from_sparql_cursor_with_default (TrackerSparqlCursor *cursor,
+                                                          PhotosQueryColumns column,
+                                                          gint64 default_value)
+{
+  TrackerSparqlValueType value_type;
+  gint64 ret_val = default_value;
+
+  value_type = tracker_sparql_cursor_get_value_type (cursor, column);
+  if (value_type == TRACKER_SPARQL_VALUE_TYPE_UNBOUND)
+    goto out;
+
+  ret_val = tracker_sparql_cursor_get_integer (cursor, column);
+
+ out:
+  return ret_val;
+}
+
+
+gint64
+photos_utils_get_mtime_from_sparql_cursor (TrackerSparqlCursor *cursor)
+{
+  const gchar *mtime_str;
+  gint64 mtime = -1;
+
+  mtime_str = tracker_sparql_cursor_get_string (cursor, PHOTOS_QUERY_COLUMNS_MTIME, NULL);
+  if (mtime_str != NULL)
+    {
+      g_autoptr (GDateTime) date_modified = NULL;
+
+      date_modified = g_date_time_new_from_iso8601 (mtime_str, NULL);
+      if (date_modified != NULL)
+        mtime = g_date_time_to_unix (date_modified);
+    }
+
+  if (mtime == -1)
+    mtime = g_get_real_time () / 1000000;
+
+  return mtime;
+}
+
+
 gchar *
 photos_utils_get_pixbuf_common_suffix (GdkPixbufFormat *format)
 {
