@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012 – 2019 Red Hat, Inc.
+ * Copyright © 2012 – 2020 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -127,6 +127,10 @@ void             photos_utils_get_controller              (PhotosWindowMode mode
                                                            PhotosOffsetController **out_offset_cntrlr,
                                                            PhotosTrackerController **out_trk_cntrlr);
 
+gdouble          photos_utils_get_double_from_sparql_cursor_with_default (TrackerSparqlCursor *cursor,
+                                                                          PhotosQueryColumns column,
+                                                                          gdouble default_value);
+
 gchar           *photos_utils_get_extension_from_mime_type (const gchar *mime_type);
 
 
@@ -134,6 +138,12 @@ gint             photos_utils_get_icon_size               (void);
 
 gint             photos_utils_get_icon_size_unscaled      (void);
 
+gint64           photos_utils_get_integer_from_sparql_cursor_with_default (TrackerSparqlCursor *cursor,
+                                                                           PhotosQueryColumns column,
+                                                                           gint64 default_value);
+
+gint64           photos_utils_get_mtime_from_sparql_cursor (TrackerSparqlCursor *cursor);
+
 char*            photos_utils_get_pixbuf_common_suffix    (GdkPixbufFormat *format);
 
 const gchar     *photos_utils_get_provider_name           (PhotosBaseManager *src_mngr, PhotosBaseItem *item);
