@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2018 – 2019 Red Hat, Inc.
+ * Copyright © 2018 – 2020 Red Hat, Inc.
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +27,7 @@
 
 #include "photos-debug.h"
 #include "photos-gegl.h"
+#include "photos-operation-insta-common.h"
 #include "photos-pipeline.h"
 
 
@@ -215,6 +216,49 @@ photos_test_pipeline_check_full (PhotosPipeline *pipeline, GeglNode *parent_expe
 }
 
 
+static void
+photos_test_pipeline_check_insta_filter (PhotosPipeline *pipeline,
+                                         PhotosOperationInstaPreset preset_expected,
+                                         PhotosOperationInstaPreset preset_compat_expected)
+{
+  g_autoptr (GSList) children = NULL;
+  GeglNode *graph;
+  GeglNode *input;
+  GeglNode *output;
+  GeglNode *previous;
+  const gchar *operation;
+  g_autofree gchar *previous_pad_name = NULL;
+  gint preset;
+  guint length;
+
+  g_assert_true (PHOTOS_IS_PIPELINE (pipeline));
+
+  graph = photos_pipeline_get_graph (pipeline);
+
+  children = gegl_node_get_children (graph);
+  length = g_slist_length (children);
+  g_assert_cmpuint (length, ==, 3);
+
+  input = gegl_node_get_input_proxy (graph, "input");
+  output = gegl_node_get_output_proxy (graph, "output");
+
+  previous = gegl_node_get_producer (output, "input", &previous_pad_name);
+  g_assert_true (previous != input);
+  g_assert_cmpstr (previous_pad_name, ==, "output");
+
+  operation = gegl_node_get_operation (GEGL_NODE (previous));
+  g_assert_cmpstr (operation, ==, "photos:magic-filter");
+
+  gegl_node_get (previous, "preset", &preset, NULL);
+  g_assert_cmpint (preset, ==, preset_expected);
+  g_assert_cmpint (preset, ==, preset_compat_expected);
+
+  previous = gegl_node_get_producer (previous, "input", &previous_pad_name);
+  g_assert_true (previous == input);
+  g_assert_cmpstr (previous_pad_name, ==, "output");
+}
+
+
 static void
 photos_test_pipeline_pipeline_new_async (GeglNode *parent,
                                          const gchar *const *filenames,
@@ -242,6 +286,314 @@ photos_test_pipeline_pipeline_new_async (GeglNode *parent,
 }
 
 
+static void
+photos_test_pipeline_insta_filter_none (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-none.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NONE,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NONE);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_1977 (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-1977.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_1977,
+                                           PHOTOS_OPERATION_INSTA_PRESET_1947);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_brannan (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-brannan.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_BRANNAN,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CALISTOGA);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_clarendon (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-clarendon.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CLARENDON,
+                                           PHOTOS_OPERATION_INSTA_PRESET_TRENCIN);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_gotham (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-gotham.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_GOTHAM,
+                                           PHOTOS_OPERATION_INSTA_PRESET_MOGADISHU);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_hefe (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-hefe.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_HEFE,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CAAP);
+}
+
+
+static void
+photos_test_pipeline_insta_filter_nashville (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-insta-filter-nashville.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NASHVILLE,
+                                           PHOTOS_OPERATION_INSTA_PRESET_HOMETOWN);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_none (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-none.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NONE,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NONE);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_1947 (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-1947.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_1947,
+                                           PHOTOS_OPERATION_INSTA_PRESET_1977);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_calistoga (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-calistoga.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CALISTOGA,
+                                           PHOTOS_OPERATION_INSTA_PRESET_BRANNAN);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_trencin (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-trencin.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_TRENCIN,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CLARENDON);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_mogadishu (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-mogadishu.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_MOGADISHU,
+                                           PHOTOS_OPERATION_INSTA_PRESET_GOTHAM);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_caap (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-caap.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_CAAP,
+                                           PHOTOS_OPERATION_INSTA_PRESET_HEFE);
+}
+
+
+static void
+photos_test_pipeline_magic_filter_hometown (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
+{
+  g_autoptr (PhotosPipeline) pipeline = NULL;
+  const gchar *const filenames[] = { "photos-test-pipeline-edited-magic-filter-hometown.xml", NULL };
+
+  photos_test_pipeline_pipeline_new_async (NULL, filenames, NULL, photos_test_pipeline_async, fixture);
+  g_main_loop_run (fixture->loop);
+
+  {
+    g_autoptr (GError) error = NULL;
+
+    pipeline = photos_pipeline_new_finish (fixture->res, &error);
+    g_assert_no_error (error);
+  }
+
+  photos_test_pipeline_check_insta_filter (pipeline,
+                                           PHOTOS_OPERATION_INSTA_PRESET_HOMETOWN,
+                                           PHOTOS_OPERATION_INSTA_PRESET_NASHVILLE);
+}
+
+
 static void
 photos_test_pipeline_no_parent_blank_uris_0 (PhotosTestPipelineFixture *fixture, gconstpointer user_data)
 {
@@ -1488,6 +1840,104 @@ main (gint argc, gchar *argv[])
   photos_gegl_init ();
   photos_gegl_ensure_builtins ();
 
+  g_test_add ("/pipeline/new/insta-filter-none",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_none,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-1977",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_1977,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-brannan",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_brannan,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-clarendon",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_clarendon,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-gotham",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_gotham,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-hefe",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_hefe,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/insta-filter-nashville",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_insta_filter_nashville,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-none",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_none,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-1947",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_1947,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-calistoga",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_calistoga,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-trencin",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_trencin,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-mogadishu",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_mogadishu,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-caap",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_caap,
+              photos_test_pipeline_teardown);
+
+  g_test_add ("/pipeline/new/magic-filter-hometown",
+              PhotosTestPipelineFixture,
+              NULL,
+              photos_test_pipeline_setup,
+              photos_test_pipeline_magic_filter_hometown,
+              photos_test_pipeline_teardown);
+
   g_test_add ("/pipeline/new/no-parent-blank-uris-0",
               PhotosTestPipelineFixture,
               NULL,
